@@ -434,8 +434,8 @@ class QiDataController:
                 else:
                     raise Exception("不支持的k线:" + str(bar_type))
 
-                for bar in bar_provider.bar_series:
-                    bar_series.insert(0, bar)
+                bar_provider.bar_series.extend(bar_series)
+                bar_series = bar_provider.bar_series
 
                 if len(bar_series) >= max_length:
                     break
@@ -451,7 +451,7 @@ class QiDataController:
 
         return bar_provider.bar_series
 
-    def load_bar_series_by_length_by_date_time(self, market, instrument_id, interval, bar_type, max_length, end_time, *instrument_ids):
+    def load_bar_series_by_length_limit_end_time(self, market, instrument_id, interval, bar_type, max_length, end_time, *instrument_ids):
         """
         根据结束时间加载指定回溯根数的历史K线（K线数据都小于等于结束时间）
         :param market:
@@ -483,7 +483,7 @@ class QiDataController:
         lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
         bar_provider = BarProvider()
         trading_time = self.instrument_manager.get_trading_time(begin_trading_date, instrument_id)
-        begin_time = YfTimeHelper.get_date_time_by_trading_day(begin_trading_date, trading_time[0].begin_time)
+        begin_time = TradingDayHelper.get_natural_date_time(begin_trading_date, trading_time[0].begin_time)
         bar_provider.create_bar_provider_by_date_time(self.instrument_manager, instrument_id, begin_time, end_time, interval, bar_type,
                                                       *instrument_ids)
         if bar_provider.bar_type == EnumBarType.second:
@@ -532,8 +532,8 @@ class QiDataController:
                 else:
                     raise Exception("不支持的k线:" + str(bar_type))
 
-                for bar in bar_provider.bar_series:
-                    bar_series.insert(0, bar)
+                bar_provider.bar_series.extend(bar_series)
+                bar_series = bar_provider.bar_series
 
                 if len(bar_series) >= max_length:
                     break
@@ -867,6 +867,37 @@ class QiDataController:
                     bar_provider.bar_series[-1].close = last_tick.last_price
                     bar_provider.bar_series[-1].trading_date = last_tick.trading_day
 
+    def load_pre_close_by_tick(self, market, instrument_id, trading_date):
+        """
+        从Tick获取pre_close
+        :param market:
+        :param instrument_id:
+        :param trading_date:
+        :return:
+        """
+        path = self.__future_tick_path
+        tick_series = []
+        try:
+            file_path = os.path.join(path, trading_date.strftime('%Y%m%d'))
+            file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".tk")
+            if instrument_id.lower() != 'index':
+                instrument = self.instrument_manager[instrument_id.split('.')[0]]
+                tick_stream = TickStream(market, instrument_id, instrument.exchange_id, file_path)
+                tick_stream.read_by_count(tick_series, 0, 5)
+        except Exception as e:
+            print(str(e))
+
+        if len(tick_series) > 0:
+            pre_close = tick_series[-1].pre_close_price
+            if pre_close != 0:
+                return pre_close
+            else:
+                print('pre_close:{0}为0,请注意.....'.format(pre_close))
+                return pre_close
+        else:
+            print('load_pre_close_by_tick:未取到Tick数据...,请注意.....')
+            return 0
+
     def on_bar(self, bar):
         """
         实盘on_bar维护策略获取的K线
